// Fetch COVID-19 data
fetch(
  'https://gist.githubusercontent.com/bhargavikondaveeti/209440046523e6eec9b6d4efc334f60f/raw/2d1ed33decd151c0aa10584d6e570f8175c5f0b0/project_covid_data.csv',
)
  .then((response) => response.text())
  .then((data) => {
    // Parse CSV data
    const parsedData = d3.csvParse(data);

    // Define WHO regions and count confirmed cases for each region
    const whoRegions = [
      'Africa',
      'Americas',
      'Eastern Mediterranean',
      'Europe',
      'South-East Asia',
      'Western Pacific',
    ];
    const confirmedCasesByRegion = {};
    whoRegions.forEach((region) => {
      confirmedCasesByRegion[region] = 0;
    });

    parsedData.forEach((d) => {
      const region = d['WHO Region'];
      const confirmed = +d['Confirmed'];
      if (confirmedCasesByRegion.hasOwnProperty(region)) {
        confirmedCasesByRegion[region] += confirmed;
      }
    });

    // Convert data to array format
    const pieData = Object.keys(confirmedCasesByRegion).map(
      (region) => ({
        region: region,
        confirmed: confirmedCasesByRegion[region],
      }),
    );

    // Define dimensions and radius for the pie chart
    const width = 400;
    const height = 400;
    const radius = Math.min(width, height) / 2;

    // Select the SVG element and append a group element
    const svg = d3
      .select('#pieChart')
      .append('g')
      .attr(
        'transform',
        `translate(${width / 2},${height / 2})`,
      );

    // Define color scale
    const color = d3.scaleOrdinal(d3.schemeCategory10);

    // Define pie layout
    const pie = d3.pie().value((d) => d.confirmed);

    // Define arc generator
    const path = d3
      .arc()
      .outerRadius(radius - 10)
      .innerRadius(0);

    // Append arcs for pie segments
    const arcs = svg
      .selectAll('arc')
      .data(pie(pieData))
      .enter()
      .append('g')
      .attr('class', 'arc');

    // Append path elements for arcs
    arcs
      .append('path')
      .attr('fill', (d, i) => color(i))
      .attr('d', path);

    // Add labels to pie segments
    arcs
      .append('text')
      .attr(
        'transform',
        (d) => `translate(${path.centroid(d)})`,
      )
      .attr('text-anchor', 'middle')
      .text((d) => d.data.region);

    // Add legend
    const legend = d3
      .select('#legend')
      .selectAll('.legend-item')
      .data(pieData)
      .enter()
      .append('div')
      .attr('class', 'legend-item');

    // Append color boxes to legend
    legend
      .append('div')
      .attr('class', 'legend-color')
      .style('background-color', (d, i) => color(i));

    // Append labels to legend
    legend
      .append('div')
      .attr('class', 'legend-label')
      .text((d) => `${d.region}: ${d.confirmed}`);
  });
