// Visualization 2: Stacked Bar Chart showing Confirmed, Deaths, and Recovered Cases by Country

// Set up SVG dimensions
var width = 800;
var height = 800;
var margin = { top: 35, right: 20, bottom: 30, left: 40 };

// Append SVG to the body
var svg2 = d3
  .select('#visualization2')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

// Load COVID-19 data
d3.csv(
  'https://gist.githubusercontent.com/Vikramkotlo09/d56978c80a3d2b425f5ca4b8fb69825f/raw/d396507f3362edb24ec40bdb4cf4d5ef4284aec7/covid%2520data',
).then(function (data) {
  // Sort data by confirmed cases in descending order
  data.sort(function (a, b) {
    return b.Confirmed - a.Confirmed;
  });

  // Take top 10 countries with highest confirmed cases
  var topCountries = data.slice(0, 10);

  // Define colors for cases
  var colorScale = d3
    .scaleOrdinal()
    .domain(['Confirmed', 'Deaths', 'Recovered'])
    .range(['#ff7f0e', '#d62728', '#2ca02c']);

  // Define scales for x and y axes
  var x = d3
    .scaleBand()
    .domain(
      topCountries.map(function (d) {
        return d['Country/Region'];
      }),
    )
    .range([margin.left, width - margin.right])
    .padding(0.1);

  var y = d3
    .scaleLinear()
    .domain([
      0,
      d3.max(topCountries, function (d) {
        return +d.Confirmed;
      }),
    ])
    .nice()
    .range([height - margin.bottom, margin.top]);

  // Draw stacked bars
  svg2
    .selectAll('.bar')
    .data(topCountries)
    .enter()
    .append('g')
    .attr('class', 'bar')
    .attr('transform', function (d) {
      return 'translate(' + x(d['Country/Region']) + ',0)';
    })
    .selectAll('rect')
    .data(function (d) {
      return ['Confirmed', 'Deaths', 'Recovered'].map(
        function (key) {
          return { key: key, value: +d[key] };
        },
      );
    })
    .enter()
    .append('rect')
    .attr('x', function (d) {
      return (
        (x.bandwidth() / 3) *
        ['Confirmed', 'Deaths', 'Recovered'].indexOf(d.key)
      );
    })
    .attr('y', function (d) {
      return y(d.value);
    })
    .attr('height', function (d) {
      return height - margin.bottom - y(d.value);
    })
    .attr('width', x.bandwidth() / 3)
    .attr('fill', function (d) {
      return colorScale(d.key);
    });

  // Add x-axis
  svg2
    .append('g')
    .attr(
      'transform',
      'translate(0,' + (height - margin.bottom) + ')',
    )
    .call(d3.axisBottom(x))
    .selectAll('text')
    .style('text-anchor', 'end')
    .attr('transform', 'rotate(-45)');

  // Add y-axis
  svg2
    .append('g')
    .attr('transform', 'translate(' + margin.left + ',0)')
    .call(d3.axisLeft(y));

  // Add chart title
  svg2
    .append('text')
    .attr('x', width / 2)
    .attr('y', margin.top / 2)
    .attr('text-anchor', 'middle')
    .style('font-size', '18px')
    .text(
      'Top 10 Countries by Confirmed, Deaths, and Recovered Cases',
    );

  // Add legend
  var legend = svg2
    .selectAll('.legend')
    .data(colorScale.domain().reverse())
    .enter()
    .append('g')
    .attr('class', 'legend')
    .attr('transform', function (d, i) {
      return 'translate(0,' + i * 20 + ')';
    });

  legend
    .append('rect')
    .attr('x', width - 18)
    .attr('width', 18)
    .attr('height', 18)
    .style('fill', colorScale);

  legend
    .append('text')
    .attr('x', width - 24)
    .attr('y', 9)
    .attr('dy', '.35em')
    .style('text-anchor', 'end')
    .text(function (d) {
      return d;
    });
});
